==> vst3sdk-docs-3.7.14_build_55-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstinterfaces/annotated_dup.js <==
var annotated_dup =
[
    [ "Steinberg", null, [
      [ "Vst", "namespaceSteinberg_1_1Vst.html", [
        [ "ChannelContext", "namespaceSteinberg_1_1Vst_1_1ChannelContext.html", [
          [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener" ]
        ] ],
        [ "AudioBusBuffers", "structSteinberg_1_1Vst_1_1AudioBusBuffers.html", "structSteinberg_1_1Vst_1_1AudioBusBuffers" ],
        [ "BusInfo", "structSteinberg_1_1Vst_1_1BusInfo.html", "structSteinberg_1_1Vst_1_1BusInfo" ],
        [ "Chord", "structSteinberg_1_1Vst_1_1Chord.html", "structSteinberg_1_1Vst_1_1Chord" ],
        [ "ChordEvent", "structSteinberg_1_1Vst_1_1ChordEvent.html", "structSteinberg_1_1Vst_1_1ChordEvent" ],
        [ "DataEvent", "structSteinberg_1_1Vst_1_1DataEvent.html", "structSteinberg_1_1Vst_1_1DataEvent" ],
        [ "DataExchangeBlock", "structSteinberg_1_1Vst_1_1DataExchangeBlock.html", "structSteinberg_1_1Vst_1_1DataExchangeBlock" ],
        [ "Event", "structSteinberg_1_1Vst_1_1Event.html", "structSteinberg_1_1Vst_1_1Event" ],
        [ "FrameRate", "structSteinberg_1_1Vst_1_1FrameRate.html", "structSteinberg_1_1Vst_1_1FrameRate" ],
        [ "IAttributeList", "classSteinberg_1_1Vst_1_1IAttributeList.html", "classSteinberg_1_1Vst_1_1IAttributeList" ],
        [ "IAudioPresentationLatency", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency" ],
        [ "IAudioProcessor", "classSteinberg_1_1Vst_1_1IAudioProcessor.html", "classSteinberg_1_1Vst_1_1IAudioProcessor" ],
        [ "IAutomationState", "classSteinberg_1_1Vst_1_1IAutomationState.html", "classSteinberg_1_1Vst_1_1IAutomationState" ],
        [ "IComponent", "classSteinberg_1_1Vst_1_1IComponent.html", "classSteinberg_1_1Vst_1_1IComponent" ],
        [ "IComponentHandler", "classSteinberg_1_1Vst_1_1IComponentHandler.html", "classSteinberg_1_1Vst_1_1IComponentHandler" ],
        [ "IComponentHandler2", "classSteinberg_1_1Vst_1_1IComponentHandler2.html", "classSteinberg_1_1Vst_1_1IComponentHandler2" ],
        [ "IComponentHandler3", "classSteinberg_1_1Vst_1_1IComponentHandler3.html", "classSteinberg_1_1Vst_1_1IComponentHandler3" ],
        [ "IComponentHandlerBusActivation", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation" ],
        [ "IComponentHandlerSystemTime", "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html", "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime" ],
        [ "IConnectionPoint", "classSteinberg_1_1Vst_1_1IConnectionPoint.html", "classSteinberg_1_1Vst_1_1IConnectionPoint" ],
        [ "IContextMenu", "classSteinberg_1_1Vst_1_1IContextMenu.html", "classSteinberg_1_1Vst_1_1IContextMenu" ],
        [ "IContextMenuItem", "structSteinberg_1_1Vst_1_1IContextMenuItem.html", "structSteinberg_1_1Vst_1_1IContextMenuItem" ],
        [ "IContextMenuTarget", "classSteinberg_1_1Vst_1_1IContextMenuTarget.html", "classSteinberg_1_1Vst_1_1IContextMenuTarget" ],
        [ "IDataExchangeHandler", "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html", "classSteinberg_1_1Vst_1_1IDataExchangeHandler" ],
        [ "IDataExchangeReceiver", "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html", "classSteinberg_1_1Vst_1_1IDataExchangeReceiver" ],
        [ "IEditController", "classSteinberg_1_1Vst_1_1IEditController.html", "classSteinberg_1_1Vst_1_1IEditController" ],
        [ "IEditController2", "classSteinberg_1_1Vst_1_1IEditController2.html", "classSteinberg_1_1Vst_1_1IEditController2" ],
        [ "IEditControllerHostEditing", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing" ],
        [ "IEventList", "classSteinberg_1_1Vst_1_1IEventList.html", "classSteinberg_1_1Vst_1_1IEventList" ],
        [ "IHostApplication", "classSteinberg_1_1Vst_1_1IHostApplication.html", "classSteinberg_1_1Vst_1_1IHostApplication" ],
        [ "IInterAppAudioConnectionNotification", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification" ],
        [ "IInterAppAudioHost", "classSteinberg_1_1Vst_1_1IInterAppAudioHost.html", "classSteinberg_1_1Vst_1_1IInterAppAudioHost" ],
        [ "IInterAppAudioPresetManager", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager" ],
        [ "IKeyswitchController", "classSteinberg_1_1Vst_1_1IKeyswitchController.html", "classSteinberg_1_1Vst_1_1IKeyswitchController" ],
        [ "IMessage", "classSteinberg_1_1Vst_1_1IMessage.html", "classSteinberg_1_1Vst_1_1IMessage" ],
        [ "IMidiLearn", "classSteinberg_1_1Vst_1_1IMidiLearn.html", "classSteinberg_1_1Vst_1_1IMidiLearn" ],
        [ "IMidiMapping", "classSteinberg_1_1Vst_1_1IMidiMapping.html", "classSteinberg_1_1Vst_1_1IMidiMapping" ],
        [ "INoteExpressionController", "classSteinberg_1_1Vst_1_1INoteExpressionController.html", "classSteinberg_1_1Vst_1_1INoteExpressionController" ],
        [ "INoteExpressionPhysicalUIMapping", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping" ],
        [ "IParameterChanges", "classSteinberg_1_1Vst_1_1IParameterChanges.html", "classSteinberg_1_1Vst_1_1IParameterChanges" ],
        [ "IParameterFinder", "classSteinberg_1_1Vst_1_1IParameterFinder.html", "classSteinberg_1_1Vst_1_1IParameterFinder" ],
        [ "IParameterFunctionName", "classSteinberg_1_1Vst_1_1IParameterFunctionName.html", "classSteinberg_1_1Vst_1_1IParameterFunctionName" ],
        [ "IParamValueQueue", "classSteinberg_1_1Vst_1_1IParamValueQueue.html", "classSteinberg_1_1Vst_1_1IParamValueQueue" ],
        [ "IPlugInterfaceSupport", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport" ],
        [ "IPrefetchableSupport", "classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", "classSteinberg_1_1Vst_1_1IPrefetchableSupport" ],
        [ "IProcessContextRequirements", "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1IProcessContextRequirements" ],
        [ "IProgramListData", "classSteinberg_1_1Vst_1_1IProgramListData.html", "classSteinberg_1_1Vst_1_1IProgramListData" ],
        [ "IProgress", "classSteinberg_1_1Vst_1_1IProgress.html", "classSteinberg_1_1Vst_1_1IProgress" ],
        [ "IRemapParamID", "classSteinberg_1_1Vst_1_1IRemapParamID.html", "classSteinberg_1_1Vst_1_1IRemapParamID" ],
        [ "IStreamAttributes", "classSteinberg_1_1Vst_1_1IStreamAttributes.html", "classSteinberg_1_1Vst_1_1IStreamAttributes" ],
        [ "ITestPlugProvider", "classSteinberg_1_1Vst_1_1ITestPlugProvider.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider" ],
        [ "ITestPlugProvider2", "classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider2" ],
        [ "IUnitData", "classSteinberg_1_1Vst_1_1IUnitData.html", "classSteinberg_1_1Vst_1_1IUnitData" ],
        [ "IUnitHandler", "classSteinberg_1_1Vst_1_1IUnitHandler.html", "classSteinberg_1_1Vst_1_1IUnitHandler" ],
        [ "IUnitHandler2", "classSteinberg_1_1Vst_1_1IUnitHandler2.html", "classSteinberg_1_1Vst_1_1IUnitHandler2" ],
        [ "IUnitInfo", "classSteinberg_1_1Vst_1_1IUnitInfo.html", "classSteinberg_1_1Vst_1_1IUnitInfo" ],
        [ "IVst3ToAAXWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html", null ],
        [ "IVst3ToAUWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html", null ],
        [ "IVst3ToVst2Wrapper", "classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html", null ],
        [ "IVst3WrapperMPESupport", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport" ],
        [ "IXmlRepresentationController", "classSteinberg_1_1Vst_1_1IXmlRepresentationController.html", "classSteinberg_1_1Vst_1_1IXmlRepresentationController" ],
        [ "KeyswitchInfo", "structSteinberg_1_1Vst_1_1KeyswitchInfo.html", "structSteinberg_1_1Vst_1_1KeyswitchInfo" ],
        [ "LegacyMIDICCOutEvent", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent.html", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent" ],
        [ "NoteExpressionTextEvent", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent" ],
        [ "NoteExpressionTypeInfo", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo" ],
        [ "NoteExpressionValueDescription", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription" ],
        [ "NoteExpressionValueEvent", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent" ],
        [ "NoteOffEvent", "structSteinberg_1_1Vst_1_1NoteOffEvent.html", "structSteinberg_1_1Vst_1_1NoteOffEvent" ],
        [ "NoteOnEvent", "structSteinberg_1_1Vst_1_1NoteOnEvent.html", "structSteinberg_1_1Vst_1_1NoteOnEvent" ],
        [ "ParameterInfo", "structSteinberg_1_1Vst_1_1ParameterInfo.html", "structSteinberg_1_1Vst_1_1ParameterInfo" ],
        [ "PhysicalUIMap", "structSteinberg_1_1Vst_1_1PhysicalUIMap.html", "structSteinberg_1_1Vst_1_1PhysicalUIMap" ],
        [ "PhysicalUIMapList", "structSteinberg_1_1Vst_1_1PhysicalUIMapList.html", "structSteinberg_1_1Vst_1_1PhysicalUIMapList" ],
        [ "PolyPressureEvent", "structSteinberg_1_1Vst_1_1PolyPressureEvent.html", "structSteinberg_1_1Vst_1_1PolyPressureEvent" ],
        [ "ProcessContext", "structSteinberg_1_1Vst_1_1ProcessContext.html", "structSteinberg_1_1Vst_1_1ProcessContext" ],
        [ "ProcessData", "structSteinberg_1_1Vst_1_1ProcessData.html", "structSteinberg_1_1Vst_1_1ProcessData" ],
        [ "ProcessSetup", "structSteinberg_1_1Vst_1_1ProcessSetup.html", "structSteinberg_1_1Vst_1_1ProcessSetup" ],
        [ "ProgramListInfo", "structSteinberg_1_1Vst_1_1ProgramListInfo.html", "structSteinberg_1_1Vst_1_1ProgramListInfo" ],
        [ "RepresentationInfo", "structSteinberg_1_1Vst_1_1RepresentationInfo.html", "structSteinberg_1_1Vst_1_1RepresentationInfo" ],
        [ "RoutingInfo", "structSteinberg_1_1Vst_1_1RoutingInfo.html", "structSteinberg_1_1Vst_1_1RoutingInfo" ],
        [ "ScaleEvent", "structSteinberg_1_1Vst_1_1ScaleEvent.html", "structSteinberg_1_1Vst_1_1ScaleEvent" ],
        [ "UnitInfo", "structSteinberg_1_1Vst_1_1UnitInfo.html", "structSteinberg_1_1Vst_1_1UnitInfo" ]
      ] ],
      [ "ITest", "classSteinberg_1_1ITest.html", "classSteinberg_1_1ITest" ],
      [ "ITestFactory", "classSteinberg_1_1ITestFactory.html", "classSteinberg_1_1ITestFactory" ],
      [ "ITestResult", "classSteinberg_1_1ITestResult.html", "classSteinberg_1_1ITestResult" ],
      [ "ITestSuite", "classSteinberg_1_1ITestSuite.html", "classSteinberg_1_1ITestSuite" ]
    ] ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstinterfaces/annotated_dup.js <==
var annotated_dup =
[
    [ "Steinberg", null, [
      [ "Vst", "namespaceSteinberg_1_1Vst.html", [
        [ "ChannelContext", "namespaceSteinberg_1_1Vst_1_1ChannelContext.html", [
          [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener" ]
        ] ],
        [ "AudioBusBuffers", "structSteinberg_1_1Vst_1_1AudioBusBuffers.html", "structSteinberg_1_1Vst_1_1AudioBusBuffers" ],
        [ "BusInfo", "structSteinberg_1_1Vst_1_1BusInfo.html", "structSteinberg_1_1Vst_1_1BusInfo" ],
        [ "Chord", "structSteinberg_1_1Vst_1_1Chord.html", "structSteinberg_1_1Vst_1_1Chord" ],
        [ "ChordEvent", "structSteinberg_1_1Vst_1_1ChordEvent.html", "structSteinberg_1_1Vst_1_1ChordEvent" ],
        [ "DataEvent", "structSteinberg_1_1Vst_1_1DataEvent.html", "structSteinberg_1_1Vst_1_1DataEvent" ],
        [ "DataExchangeBlock", "structSteinberg_1_1Vst_1_1DataExchangeBlock.html", "structSteinberg_1_1Vst_1_1DataExchangeBlock" ],
        [ "Event", "structSteinberg_1_1Vst_1_1Event.html", "structSteinberg_1_1Vst_1_1Event" ],
        [ "FrameRate", "structSteinberg_1_1Vst_1_1FrameRate.html", "structSteinberg_1_1Vst_1_1FrameRate" ],
        [ "IAttributeList", "classSteinberg_1_1Vst_1_1IAttributeList.html", "classSteinberg_1_1Vst_1_1IAttributeList" ],
        [ "IAudioPresentationLatency", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency" ],
        [ "IAudioProcessor", "classSteinberg_1_1Vst_1_1IAudioProcessor.html", "classSteinberg_1_1Vst_1_1IAudioProcessor" ],
        [ "IAutomationState", "classSteinberg_1_1Vst_1_1IAutomationState.html", "classSteinberg_1_1Vst_1_1IAutomationState" ],
        [ "IComponent", "classSteinberg_1_1Vst_1_1IComponent.html", "classSteinberg_1_1Vst_1_1IComponent" ],
        [ "IComponentHandler", "classSteinberg_1_1Vst_1_1IComponentHandler.html", "classSteinberg_1_1Vst_1_1IComponentHandler" ],
        [ "IComponentHandler2", "classSteinberg_1_1Vst_1_1IComponentHandler2.html", "classSteinberg_1_1Vst_1_1IComponentHandler2" ],
        [ "IComponentHandler3", "classSteinberg_1_1Vst_1_1IComponentHandler3.html", "classSteinberg_1_1Vst_1_1IComponentHandler3" ],
        [ "IComponentHandlerBusActivation", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html", "classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation" ],
        [ "IComponentHandlerSystemTime", "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html", "classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime" ],
        [ "IConnectionPoint", "classSteinberg_1_1Vst_1_1IConnectionPoint.html", "classSteinberg_1_1Vst_1_1IConnectionPoint" ],
        [ "IContextMenu", "classSteinberg_1_1Vst_1_1IContextMenu.html", "classSteinberg_1_1Vst_1_1IContextMenu" ],
        [ "IContextMenuItem", "structSteinberg_1_1Vst_1_1IContextMenuItem.html", "structSteinberg_1_1Vst_1_1IContextMenuItem" ],
        [ "IContextMenuTarget", "classSteinberg_1_1Vst_1_1IContextMenuTarget.html", "classSteinberg_1_1Vst_1_1IContextMenuTarget" ],
        [ "IDataExchangeHandler", "classSteinberg_1_1Vst_1_1IDataExchangeHandler.html", "classSteinberg_1_1Vst_1_1IDataExchangeHandler" ],
        [ "IDataExchangeReceiver", "classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html", "classSteinberg_1_1Vst_1_1IDataExchangeReceiver" ],
        [ "IEditController", "classSteinberg_1_1Vst_1_1IEditController.html", "classSteinberg_1_1Vst_1_1IEditController" ],
        [ "IEditController2", "classSteinberg_1_1Vst_1_1IEditController2.html", "classSteinberg_1_1Vst_1_1IEditController2" ],
        [ "IEditControllerHostEditing", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html", "classSteinberg_1_1Vst_1_1IEditControllerHostEditing" ],
        [ "IEventList", "classSteinberg_1_1Vst_1_1IEventList.html", "classSteinberg_1_1Vst_1_1IEventList" ],
        [ "IHostApplication", "classSteinberg_1_1Vst_1_1IHostApplication.html", "classSteinberg_1_1Vst_1_1IHostApplication" ],
        [ "IInterAppAudioConnectionNotification", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html", "classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification" ],
        [ "IInterAppAudioHost", "classSteinberg_1_1Vst_1_1IInterAppAudioHost.html", "classSteinberg_1_1Vst_1_1IInterAppAudioHost" ],
        [ "IInterAppAudioPresetManager", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html", "classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager" ],
        [ "IKeyswitchController", "classSteinberg_1_1Vst_1_1IKeyswitchController.html", "classSteinberg_1_1Vst_1_1IKeyswitchController" ],
        [ "IMessage", "classSteinberg_1_1Vst_1_1IMessage.html", "classSteinberg_1_1Vst_1_1IMessage" ],
        [ "IMidiLearn", "classSteinberg_1_1Vst_1_1IMidiLearn.html", "classSteinberg_1_1Vst_1_1IMidiLearn" ],
        [ "IMidiLearn2", "classSteinberg_1_1Vst_1_1IMidiLearn2.html", "classSteinberg_1_1Vst_1_1IMidiLearn2" ],
        [ "IMidiMapping", "classSteinberg_1_1Vst_1_1IMidiMapping.html", "classSteinberg_1_1Vst_1_1IMidiMapping" ],
        [ "IMidiMapping2", "classSteinberg_1_1Vst_1_1IMidiMapping2.html", "classSteinberg_1_1Vst_1_1IMidiMapping2" ],
        [ "INoteExpressionController", "classSteinberg_1_1Vst_1_1INoteExpressionController.html", "classSteinberg_1_1Vst_1_1INoteExpressionController" ],
        [ "INoteExpressionPhysicalUIMapping", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html", "classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping" ],
        [ "IParameterChanges", "classSteinberg_1_1Vst_1_1IParameterChanges.html", "classSteinberg_1_1Vst_1_1IParameterChanges" ],
        [ "IParameterFinder", "classSteinberg_1_1Vst_1_1IParameterFinder.html", "classSteinberg_1_1Vst_1_1IParameterFinder" ],
        [ "IParameterFunctionName", "classSteinberg_1_1Vst_1_1IParameterFunctionName.html", "classSteinberg_1_1Vst_1_1IParameterFunctionName" ],
        [ "IParamValueQueue", "classSteinberg_1_1Vst_1_1IParamValueQueue.html", "classSteinberg_1_1Vst_1_1IParamValueQueue" ],
        [ "IPlugInterfaceSupport", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html", "classSteinberg_1_1Vst_1_1IPlugInterfaceSupport" ],
        [ "IPrefetchableSupport", "classSteinberg_1_1Vst_1_1IPrefetchableSupport.html", "classSteinberg_1_1Vst_1_1IPrefetchableSupport" ],
        [ "IProcessContextRequirements", "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1IProcessContextRequirements" ],
        [ "IProgramListData", "classSteinberg_1_1Vst_1_1IProgramListData.html", "classSteinberg_1_1Vst_1_1IProgramListData" ],
        [ "IProgress", "classSteinberg_1_1Vst_1_1IProgress.html", "classSteinberg_1_1Vst_1_1IProgress" ],
        [ "IRemapParamID", "classSteinberg_1_1Vst_1_1IRemapParamID.html", "classSteinberg_1_1Vst_1_1IRemapParamID" ],
        [ "IStreamAttributes", "classSteinberg_1_1Vst_1_1IStreamAttributes.html", "classSteinberg_1_1Vst_1_1IStreamAttributes" ],
        [ "ITestPlugProvider", "classSteinberg_1_1Vst_1_1ITestPlugProvider.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider" ],
        [ "ITestPlugProvider2", "classSteinberg_1_1Vst_1_1ITestPlugProvider2.html", "classSteinberg_1_1Vst_1_1ITestPlugProvider2" ],
        [ "IUnitData", "classSteinberg_1_1Vst_1_1IUnitData.html", "classSteinberg_1_1Vst_1_1IUnitData" ],
        [ "IUnitHandler", "classSteinberg_1_1Vst_1_1IUnitHandler.html", "classSteinberg_1_1Vst_1_1IUnitHandler" ],
        [ "IUnitHandler2", "classSteinberg_1_1Vst_1_1IUnitHandler2.html", "classSteinberg_1_1Vst_1_1IUnitHandler2" ],
        [ "IUnitInfo", "classSteinberg_1_1Vst_1_1IUnitInfo.html", "classSteinberg_1_1Vst_1_1IUnitInfo" ],
        [ "IVst3ToAAXWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html", null ],
        [ "IVst3ToAUWrapper", "classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html", null ],
        [ "IVst3ToVst2Wrapper", "classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html", null ],
        [ "IVst3WrapperMPESupport", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html", "classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport" ],
        [ "IXmlRepresentationController", "classSteinberg_1_1Vst_1_1IXmlRepresentationController.html", "classSteinberg_1_1Vst_1_1IXmlRepresentationController" ],
        [ "KeyswitchInfo", "structSteinberg_1_1Vst_1_1KeyswitchInfo.html", "structSteinberg_1_1Vst_1_1KeyswitchInfo" ],
        [ "LegacyMIDICCOutEvent", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent.html", "structSteinberg_1_1Vst_1_1LegacyMIDICCOutEvent" ],
        [ "Midi1ControllerParamIDAssignment", "structSteinberg_1_1Vst_1_1Midi1ControllerParamIDAssignment.html", "structSteinberg_1_1Vst_1_1Midi1ControllerParamIDAssignment" ],
        [ "Midi1ControllerParamIDAssignmentList", "structSteinberg_1_1Vst_1_1Midi1ControllerParamIDAssignmentList.html", "structSteinberg_1_1Vst_1_1Midi1ControllerParamIDAssignmentList" ],
        [ "Midi2Controller", "structSteinberg_1_1Vst_1_1Midi2Controller.html", "structSteinberg_1_1Vst_1_1Midi2Controller" ],
        [ "Midi2ControllerParamIDAssignment", "structSteinberg_1_1Vst_1_1Midi2ControllerParamIDAssignment.html", "structSteinberg_1_1Vst_1_1Midi2ControllerParamIDAssignment" ],
        [ "Midi2ControllerParamIDAssignmentList", "structSteinberg_1_1Vst_1_1Midi2ControllerParamIDAssignmentList.html", "structSteinberg_1_1Vst_1_1Midi2ControllerParamIDAssignmentList" ],
        [ "NoteExpressionIntValueEvent", "structSteinberg_1_1Vst_1_1NoteExpressionIntValueEvent.html", "structSteinberg_1_1Vst_1_1NoteExpressionIntValueEvent" ],
        [ "NoteExpressionTextEvent", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent.html", "structSteinberg_1_1Vst_1_1NoteExpressionTextEvent" ],
        [ "NoteExpressionTypeInfo", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html", "structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo" ],
        [ "NoteExpressionValueDescription", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html", "structSteinberg_1_1Vst_1_1NoteExpressionValueDescription" ],
        [ "NoteExpressionValueEvent", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent.html", "structSteinberg_1_1Vst_1_1NoteExpressionValueEvent" ],
        [ "NoteOffEvent", "structSteinberg_1_1Vst_1_1NoteOffEvent.html", "structSteinberg_1_1Vst_1_1NoteOffEvent" ],
        [ "NoteOnEvent", "structSteinberg_1_1Vst_1_1NoteOnEvent.html", "structSteinberg_1_1Vst_1_1NoteOnEvent" ],
        [ "ParameterInfo", "structSteinberg_1_1Vst_1_1ParameterInfo.html", "structSteinberg_1_1Vst_1_1ParameterInfo" ],
        [ "PhysicalUIMap", "structSteinberg_1_1Vst_1_1PhysicalUIMap.html", "structSteinberg_1_1Vst_1_1PhysicalUIMap" ],
        [ "PhysicalUIMapList", "structSteinberg_1_1Vst_1_1PhysicalUIMapList.html", "structSteinberg_1_1Vst_1_1PhysicalUIMapList" ],
        [ "PolyPressureEvent", "structSteinberg_1_1Vst_1_1PolyPressureEvent.html", "structSteinberg_1_1Vst_1_1PolyPressureEvent" ],
        [ "ProcessContext", "structSteinberg_1_1Vst_1_1ProcessContext.html", "structSteinberg_1_1Vst_1_1ProcessContext" ],
        [ "ProcessData", "structSteinberg_1_1Vst_1_1ProcessData.html", "structSteinberg_1_1Vst_1_1ProcessData" ],
        [ "ProcessSetup", "structSteinberg_1_1Vst_1_1ProcessSetup.html", "structSteinberg_1_1Vst_1_1ProcessSetup" ],
        [ "ProgramListInfo", "structSteinberg_1_1Vst_1_1ProgramListInfo.html", "structSteinberg_1_1Vst_1_1ProgramListInfo" ],
        [ "RepresentationInfo", "structSteinberg_1_1Vst_1_1RepresentationInfo.html", "structSteinberg_1_1Vst_1_1RepresentationInfo" ],
        [ "RoutingInfo", "structSteinberg_1_1Vst_1_1RoutingInfo.html", "structSteinberg_1_1Vst_1_1RoutingInfo" ],
        [ "ScaleEvent", "structSteinberg_1_1Vst_1_1ScaleEvent.html", "structSteinberg_1_1Vst_1_1ScaleEvent" ],
        [ "UnitInfo", "structSteinberg_1_1Vst_1_1UnitInfo.html", "structSteinberg_1_1Vst_1_1UnitInfo" ]
      ] ],
      [ "ITest", "classSteinberg_1_1ITest.html", "classSteinberg_1_1ITest" ],
      [ "ITestFactory", "classSteinberg_1_1ITestFactory.html", "classSteinberg_1_1ITestFactory" ],
      [ "ITestResult", "classSteinberg_1_1ITestResult.html", "classSteinberg_1_1ITestResult" ],
      [ "ITestSuite", "classSteinberg_1_1ITestSuite.html", "classSteinberg_1_1ITestSuite" ],
      [ "IWaylandFrame", "classSteinberg_1_1IWaylandFrame.html", "classSteinberg_1_1IWaylandFrame" ],
      [ "IWaylandHost", "classSteinberg_1_1IWaylandHost.html", "classSteinberg_1_1IWaylandHost" ]
    ] ]
];
